/*
 * FILE:    GUI.java
 * AUTHORS: Kristian Hasler
 * 
 * Copyright (c) 1999 University College London
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, is permitted, for non-commercial use only, provided
 * that the following conditions are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 3. All advertising materials mentioning features or use of this software
 *    must display the following acknowledgement:
 *      This product includes software developed by the Computer Science
 *      Department at University College London
 * 4. Neither the name of the University nor of the Department may be used
 *    to endorse or promote products derived from this software without
 *    specific prior written permission.
 * Use of this software for commercial purposes is explicitly forbidden
 * unless prior written permission is obtained from the authors.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHORS AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESSED OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHORS OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 */
 
import java.awt.*;
import java.applet.*;
import java.util.*;

class GUI extends Panel
{
	private TextArea sessionDesc;
 	public Button[] button;
	public Button startButton;
	private Label[] label;
	private Label sessionTitle;
	private Panel panel1, panel2, panelStart, panelDesc, panelInfo, panelTool;
	private Font font;
	private int fontSize;

    public GUI() {
		button=new Button[4];
		label=new Label[4];

		if ((System.getProperty("os.name")).startsWith("Windows")) fontSize=11;
			else fontSize=10;
		font=new Font("Helvetica", Font.PLAIN, fontSize);
		setFont(font);

		setLayout(new BorderLayout(10,10));

		// Three main panels - 1st for session info, 2nd for tools, 3rd for start button
		panelInfo=new Panel();
		panelTool=new Panel();
		panelInfo.setLayout(new BorderLayout(10,5));
		panelTool.setLayout(new FlowLayout(FlowLayout.CENTER,15,5));
		add ("North",panelInfo);
		add ("Center",panelTool);

		// Panels for session description/title and start button
		panelDesc=new Panel();
		panelStart=new Panel();
		panelDesc.setLayout(new BorderLayout());
		panelInfo.add ("North",panelDesc);
		panelInfo.add ("South",panelStart);

		//Panels for tool buttons and address/port/ttl info
		panel1=new Panel();
		panel2=new Panel();
        panel1.setLayout(new GridLayout(4,1,5,5));
        panel2.setLayout(new GridLayout(4,1,5,5));
		panelTool.add ("West",panel1);
		panelTool.add ("East",panel2);

		panelStart.add("Center",startButton=new Button("Join Conference"));
	}

	public void AddTool(int tool, String media, String address, String port, String ttl, String key) {
		panel1.add(button[tool]=new Button(media));
		panel2.add(label[tool]=new Label("Address: "+address+"  Port: "+port+"  TTL: "+ttl+"   Key: "+key,Label.LEFT));
	}

	public void AddTitle(String title) {
		panelDesc.add ("Center", sessionTitle=new Label(title, Label.CENTER));
	}

	public void AddDesc(String fixstr) {
		StringBuffer str=new StringBuffer(fixstr);
		for (int i=80; i<(str.length()); i+=80) {
			str.insert (i, "\n");
		}
		fixstr=str.toString();
		panelDesc.add ("South", sessionDesc=new TextArea(fixstr, 5, 60, TextArea.SCROLLBARS_VERTICAL_ONLY));
		sessionDesc.setEditable(false);
	}
}